===============================
busybees
===============================

.. image:: https://img.shields.io/travis/iansmcf/busybees.svg
        :target: https://travis-ci.org/iansmcf/busybees

.. image:: https://img.shields.io/pypi/v/busybees.svg
        :target: https://pypi.python.org/pypi/busybees


An implementation of threading that abstracts away the threading.

* Free software: BSD license
* Documentation: https://busybees.readthedocs.org.

Features
--------

* TODO
